@echo off
::
:: Sign TWAIN DSM v1.0
:: Unzip a zip file, sign the contents, rezip it...
::

::
:: Make sure we have visual studio community installed...
::
echo Make sure Visual Studio Community is installed.
if not exist "C:\Program Files (x86)\Microsoft Visual Studio\2017\Community\Common7\Tools\VsDevCmd.bat" (
	echo Please install Visual Studio Community.
	pause
	goto:EOF
)

::
:: Make sure we have 7zip installed...
::
echo Make sure 7zip is installed.
if not exist "c:\Program Files\7-Zip\7z.exe" (
	echo Please install 7zip.
	pause
	goto:EOF
)

::
:: Make sure we have our TWAINDSM.zip file...
::
echo Check for the files we want to sign: TWAINDSM.zip
if not exist TWAINDSM.Zip (
	echo Couldn't find the TWAINDSM.zip file.
	pause
	goto:EOF
)

::
:: Make sure we have our signing certificate file...
::
echo Check for our signing certificate: TwainWorkingGroupCertificate.pfx
if not exist TwainWorkingGroupCertificate.pfx (
	echo Couldn't find the TwainWorkingGroupCertificate.pfx file.
	pause
	goto:EOF
)

::
:: Initialize...
::
echo Initialize this folder.
if exist TWAINDSM (
	rmdir /s /q TWAINDSM >NUL
)
if exist TWAINDSM_Signed.zip (
	del /f /q TWAINDSM_Signed.zip >NUL
)

::
:: Unzip the file...
::
echo Unzip TWAINDSM.zip.
"c:\Program Files\7-Zip\7z" x "TWAINDSM.zip" -ptwg >NUL

::
:: Load the Visual Studio environment variables...
::
echo Load the Visual Studio environment.
call "C:\Program Files (x86)\Microsoft Visual Studio\2017\Community\Common7\Tools\VsDevCmd.bat" >NUL

::
:: Sign the 32-bit DSM...
::
echo sign the 32-bit DSM.
signtool.exe^
	sign^
	/v^
	/p "putyourpasswordhere"^
	/f "TwainWorkingGroupCertificate.pfx"^
	/t http://timestamp.verisign.com/scripts/timstamp.dll^
	TWAINDSM\32\TWAINDSM.DLL >NUL
if "%errorlevel%" NEQ "0" (
	echo Signing failed - 32-bit
	pause
	goto:EOF
)

::
:: Sign the 64-bit DSM...
::
echo sign the 64-bit DSM.
signtool.exe^
	sign^
	/v^
	/p "putyourpasswordhere"^
	/f "TwainWorkingGroupCertificate.pfx"^
	/t http://timestamp.verisign.com/scripts/timstamp.dll^
	TWAINDSM\64\TWAINDSM.DLL >NUL
if "%errorlevel%" NEQ "0" (
	echo Signing failed - 64-bit
	pause
	goto:EOF
)

::
:: Zip up the results...
::
echo Zip up the signed files into TWAINDSM_Signed.zip.
"c:\Program Files\7-Zip\7z" a "TWAINDSM_Signed.zip" -ptwg "TWAINDSM" >NUL

::
:: Cleanup...
::
echo Cleanup.
rmdir /s /q TWAINDSM >NUL

echo.
echo.
echo *****************************************************************
echo * Signing was successful!                                       *
echo * Please send the TWAINDSM_Signed.zip file to whoever needs it. *
echo *****************************************************************
pause